==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/lt_LT.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Įkeliama peržiūra…",
    "Saved" : "Įrašyta",
    "Admin" : "Administravimas",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "Name cannot be empty" : "Pavadinimas negali būti tuščias",
    "The given name is too long" : "Nurodytas pavadinimas yra per ilgas",
    "The given web address is too long" : "Nurodytas adresas yra per ilgas",
    "The given legal notice address is too long" : "Nurodytas teisinio pranešimo adresas yra per ilgas",
    "The given privacy policy address is too long" : "Nurodytas privatumo politikos adresas yra per ilgas",
    "The given slogan is too long" : "Nurodytas šūkis yra per ilgas",
    "The given color is invalid" : "Nurodyta spalva yra neteisinga",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeliamas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded" : "Neįkeltas joks failas",
    "Unsupported image type" : "Nepalaikomas paveikslo tipas",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Jūs jau naudojate tinkintą apipavidalinimą. Apipavidalinimo programėlės nustatymai gali būti perrašyti to apipavidalinimo.",
    "Theming" : "Apipavidalinimas",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "Adjust the Nextcloud theme" : "Derinti Nextcloud apipavidalinimą",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temos leidžia lengvai tinkinti jūsų egzemplioriaus ir palaikomų klientų išvaizdą ir turinį. Tai bus matoma visiems naudotojams. ",
    "Name" : "Pavadinimas",
    "Reset to default" : "Atstatyti į numatytąją",
    "Web link" : "Internetinė nuoroda",
    "https://…" : "https://…",
    "Slogan" : "Šūkis",
    "Color" : "Spalva",
    "Logo" : "Logotipas",
    "Upload new logo" : "Įkelti naują logotipą",
    "Login image" : "Prisijungimo paveikslas",
    "Upload new login background" : "Įkelti naują prisijungimo foną",
    "Remove background image" : "Šalinti foninį paveikslą",
    "Advanced options" : "Išplėstinės parinktys",
    "Legal notice link" : "Teisinio pranešimo nuoroda",
    "Privacy policy link" : "Privatumo politikos nuoroda",
    "Header logo" : "Antraštės logotipas",
    "Upload new header logo" : "Įkelti naują antraštės logotipą",
    "Favicon" : "Svetainės piktograma",
    "Upload new favicon" : "Įkelti naują svetainės piktogramą",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Norėdami automatiškai generuoti svetainės piktogramą remiantis įkeltu logotipu ir spalva, įdiekite Imagemagick PHP plėtinį su SVG paveikslų palaikymu."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/lt_LT.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Įkeliama peržiūra…",
    "Saved" : "Įrašyta",
    "Admin" : "Administravimas",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "Name cannot be empty" : "Pavadinimas negali būti tuščias",
    "The given name is too long" : "Nurodytas pavadinimas yra per ilgas",
    "The given web address is too long" : "Nurodytas adresas yra per ilgas",
    "The given legal notice address is too long" : "Nurodytas teisinio pranešimo adresas yra per ilgas",
    "The given privacy policy address is too long" : "Nurodytas privatumo politikos adresas yra per ilgas",
    "The given slogan is too long" : "Nurodytas šūkis yra per ilgas",
    "The given color is invalid" : "Nurodyta spalva yra neteisinga",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeliamas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded" : "Neįkeltas joks failas",
    "Unsupported image type" : "Nepalaikomas paveikslo tipas",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Jūs jau naudojate tinkintą apipavidalinimą. Apipavidalinimo programėlės nustatymai gali būti perrašyti to apipavidalinimo.",
    "Theming" : "Apipavidalinimas",
    "Legal notice" : "Teisinis pranešimas",
    "Privacy policy" : "Privatumo politika",
    "Adjust the Nextcloud theme" : "Derinti Nextcloud apipavidalinimą",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Apipavidalinimai leidžia lengvai tinkinti jūsų egzemplioriaus ir palaikomų klientų išvaizdą bei turinį. Tai bus matoma visiems naudotojams.",
    "Name" : "Pavadinimas",
    "Reset to default" : "Atstatyti į numatytąją",
    "Web link" : "Internetinė nuoroda",
    "https://…" : "https://…",
    "Slogan" : "Šūkis",
    "Color" : "Spalva",
    "Logo" : "Logotipas",
    "Upload new logo" : "Įkelti naują logotipą",
    "Login image" : "Prisijungimo paveikslas",
    "Upload new login background" : "Įkelti naują prisijungimo foną",
    "Remove background image" : "Šalinti foninį paveikslą",
    "Advanced options" : "Išplėstinės parinktys",
    "Legal notice link" : "Teisinio pranešimo nuoroda",
    "Privacy policy link" : "Privatumo politikos nuoroda",
    "Header logo" : "Antraštės logotipas",
    "Upload new header logo" : "Įkelti naują antraštės logotipą",
    "Favicon" : "Svetainės piktograma",
    "Upload new favicon" : "Įkelti naują svetainės piktogramą",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Norėdami automatiškai generuoti svetainės piktogramą remiantis įkeltu logotipu ir spalva, įdiekite Imagemagick PHP plėtinį su SVG paveikslų palaikymu."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
